@@ -1,6 +1,7 @@
 from django.contrib import admin
 from edc_adverse_event.modeladmin_mixins import AeFollowupModelAdminMixin
 from edc_model_admin.history import SimpleHistoryAdmin
+from edc_sites.admin import SiteModelAdminMixin
 
 from ..admin_site import intecomm_ae_admin
 from ..forms import AeFollowupForm
@@ -8,6 +9,5 @@ from ..models import AeFollowup
 
 
 @admin.register(AeFollowup, site=intecomm_ae_admin)
-class AeFollowupAdmin(AeFollowupModelAdminMixin, SimpleHistoryAdmin):
-
+class AeFollowupAdmin(SiteModelAdminMixin, AeFollowupModelAdminMixin, SimpleHistoryAdmin):
     form = AeFollowupForm
