@@ -3,6 +3,7 @@ from django.utils.html import format_html
 from edc_adverse_event.modeladmin_mixins import AeInitialModelAdminMixin
 from edc_model_admin.history import SimpleHistoryAdmin
 from edc_notification.utils import get_email_contacts
+from edc_sites.admin import SiteModelAdminMixin
 
 from ..admin_site import intecomm_ae_admin
 from ..forms import AeInitialForm
@@ -10,8 +11,7 @@ from ..models import AeInitial
 
 
 @admin.register(AeInitial, site=intecomm_ae_admin)
-class AeInitialAdmin(AeInitialModelAdminMixin, SimpleHistoryAdmin):
-
+class AeInitialAdmin(SiteModelAdminMixin, AeInitialModelAdminMixin, SimpleHistoryAdmin):
     form = AeInitialForm
     email_contact = get_email_contacts("ae_reports")
     additional_instructions = format_html(
