@@ -1,6 +1,7 @@
 from django.contrib import admin
 from edc_adverse_event.modeladmin_mixins import AeSusarModelAdminMixin
 from edc_model_admin.history import SimpleHistoryAdmin
+from edc_sites.admin import SiteModelAdminMixin
 
 from ..admin_site import intecomm_ae_admin
 from ..forms import AeSusarForm
@@ -8,6 +9,5 @@ from ..models import AeSusar
 
 
 @admin.register(AeSusar, site=intecomm_ae_admin)
-class AeSusarAdmin(AeSusarModelAdminMixin, SimpleHistoryAdmin):
-
+class AeSusarAdmin(SiteModelAdminMixin, AeSusarModelAdminMixin, SimpleHistoryAdmin):
     form = AeSusarForm
