@@ -1,6 +1,7 @@
 from django.contrib import admin
 from edc_adverse_event.modeladmin_mixins import AeTmgModelAdminMixin
 from edc_model_admin.history import SimpleHistoryAdmin
+from edc_sites.admin import SiteModelAdminMixin
 
 from ..admin_site import intecomm_ae_admin
 from ..forms import AeTmgForm
@@ -8,6 +9,5 @@ from ..models import AeTmg
 
 
 @admin.register(AeTmg, site=intecomm_ae_admin)
-class AeTmgAdmin(AeTmgModelAdminMixin, SimpleHistoryAdmin):
-
+class AeTmgAdmin(SiteModelAdminMixin, AeTmgModelAdminMixin, SimpleHistoryAdmin):
     form = AeTmgForm
