@@ -6,8 +6,7 @@ from ..model_mixins import DeathReportModelMixin as MyDeathReportModelMixin
 
 
 class DeathReport(MyDeathReportModelMixin, DeathReportModelMixin, BaseUuidModel):
-
     study_day = models.IntegerField(default=0, editable=False, help_text="not used")
 
-    class Meta(DeathReportModelMixin.Meta):
+    class Meta(DeathReportModelMixin.Meta, BaseUuidModel.Meta):
         pass
