@@ -18,7 +18,6 @@ subjectconsent = Recipe(
     consent_reviewed=YES,
     consent_signature=YES,
     dob=get_utcnow() - relativedelta(years=25),
-    first_name=fake.first_name,
     gender="M",
     identity=seq("12315678"),
     identity_type="country_id",
@@ -26,7 +25,6 @@ subjectconsent = Recipe(
     is_dob_estimated="-",
     is_incarcerated=NO,
     is_literate=YES,
-    last_name=fake.last_name,
     screening_identifier=None,
     study_questions=YES,
     site=Site.objects.get_current(),
