@@ -1,6 +1,7 @@
 from .ae_initial_model_wrapper import AeInitialModelWrapper
+from .appointment_model_wrapper import AppointmentModelWrapper
+from .consent_refusal_model_wrapper import ConsentRefusalModelWrapper
 from .death_report_model_wrapper import DeathReportModelWrapper
 from .patient_log_model_wrapper import PatientLogModelWrapper
 from .subject_consent_model_wrappers import SubjectConsentModelWrapper
-from .subject_refusal_model_wrapper import SubjectRefusalModelWrapper
 from .subject_screening_model_wrapper import SubjectScreeningModelWrapper
