@@ -1,5 +1,5 @@
 from .ae import AeListboardView, DeathReportListboardView
 from .screening import ListboardView as ScreenGroupListboardView
-from .subject import InteSubjectListboardView  # SubjectListboardView
 from .subject import CommSubjectListboardView
 from .subject import DashboardView as SubjectDashboardView
+from .subject import InteSubjectListboardView
