@@ -6,15 +6,17 @@ from .defaults import *  # noqa
 
 print(f"Settings file {__file__}")
 
+# IF UAT, PATIENT IDENTIFIERS MAY START WITH 999
+# EDC_PROTOCOL_NUMBER = 999
 # UG
 # SITE_ID = SiteID(default=101)  # Kasangati
 # SITE_ID = SiteID(default=102)  # Kisugu
-# SITE_ID = SiteID(default=103)  # Kiswa
+SITE_ID = SiteID(default=103)  # Kiswa
 # SITE_ID = SiteID(default=104)  # Kyazanga
 # SITE_ID = SiteID(default=105)  # Mpigi
 # SITE_ID = SiteID(default=106)  # Namayumba
 # SITE_ID = SiteID(default=107)  # Namulonge
-SITE_ID = SiteID(default=108)  # Ndejje
+# SITE_ID = SiteID(default=108)  # Ndejje
 # SITE_ID = SiteID(default=109)  # Sekiwunga
 # SITE_ID = SiteID(default=110)  # Wakiso
 
