@@ -63,7 +63,7 @@ ETC_DIR = env.str("DJANGO_ETC_FOLDER")
 
 TEST_DIR = os.path.join(BASE_DIR, APP_NAME, "tests")
 
-# INTERNAL_IPS = ["127.0.0.1"]
+# INTERNAL_IPS = ["127.0.0.1"] # for djdt
 ALLOWED_HOSTS = ["*"]  # env.list('DJANGO_ALLOWED_HOSTS')
 
 ENFORCE_RELATED_ACTION_ITEM_EXISTS = False
@@ -89,6 +89,7 @@ INSTALLED_APPS = [
     "django_crypto_fields.apps.AppConfig",
     "django_revision.apps.AppConfig",
     # "django_extensions",
+    # "debug_toolbar",
     "logentry_admin",
     "simple_history",
     "storages",
@@ -111,6 +112,7 @@ INSTALLED_APPS = [
     "edc_facility.apps.AppConfig",
     "edc_fieldsets.apps.AppConfig",
     "edc_form_validators.apps.AppConfig",
+    "edc_he.apps.AppConfig",
     "edc_lab_dashboard.apps.AppConfig",
     "edc_label.apps.AppConfig",
     "edc_list_data.apps.AppConfig",
@@ -122,6 +124,7 @@ INSTALLED_APPS = [
     "edc_model_fields.apps.AppConfig",
     "edc_model_admin.apps.AppConfig",
     "edc_navbar.apps.AppConfig",
+    "edc_next_appointment.apps.AppConfig",
     "edc_notification.apps.AppConfig",
     "edc_offstudy.apps.AppConfig",
     "edc_pharmacy.apps.AppConfig",
@@ -129,6 +132,7 @@ INSTALLED_APPS = [
     "edc_protocol.apps.AppConfig",
     "edc_protocol_incident.apps.AppConfig",
     "edc_prn.apps.AppConfig",
+    "edc_qol.apps.AppConfig",
     "edc_randomization.apps.AppConfig",
     "edc_reference.apps.AppConfig",
     "edc_refusal.apps.AppConfig",
@@ -148,6 +152,7 @@ INSTALLED_APPS = [
     "intecomm_consent.apps.AppConfig",
     "intecomm_lists.apps.AppConfig",
     "intecomm_dashboard.apps.AppConfig",
+    "intecomm_facility.apps.AppConfig",
     "intecomm_labs.apps.AppConfig",
     "intecomm_subject.apps.AppConfig",
     "intecomm_visit_schedule.apps.AppConfig",
@@ -165,6 +170,7 @@ if not DEFENDER_ENABLED:
     INSTALLED_APPS.pop(INSTALLED_APPS.index("defender"))
 
 MIDDLEWARE = [
+    # "debug_toolbar.middleware.DebugToolbarMiddleware",
     "django.middleware.security.SecurityMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
     "django.middleware.common.CommonMiddleware",
@@ -302,6 +308,8 @@ DATETIME_FORMAT = "j N Y H:i"
 SHORT_DATE_FORMAT = "d/m/Y"
 SHORT_DATETIME_FORMAT = "d/m/Y H:i"
 
+REPORT_DATETIME_FIELD_NAME = "report_datetime"
+
 # See also any inte_* or edc_* apps.py
 DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
 
@@ -320,6 +328,17 @@ EDC_APPOINTMENT_APPT_REASON_CHOICES = (
     (UNSCHEDULED_APPT, "Routine / Unscheduled (non-study)"),
 )
 
+# edc-export
+EDC_EXPORT_EXPORT_PII_USERS = env.list("EDC_EXPORT_EXPORT_PII_USERS")
+EDC_FACILITY_HEALTH_FACILITY_MODEL = "intecomm_facility.healthfacility"
+
+# edc-he
+EDC_HE_ASSETS_MODEL = "intecomm_subject.healtheconomicsassets"
+EDC_HE_HOUSEHOLDHEAD_MODEL = "intecomm_subject.healtheconomicshouseholdhead"
+EDC_HE_INCOME_MODEL = "intecomm_subject.healtheconomicsincome"
+EDC_HE_PATIENT_MODEL = "intecomm_subject.healtheconomicspatient"
+EDC_HE_PROPERTY_MODEL = "intecomm_subject.healtheconomicsproperty"
+
 # edc-pdutils
 EXPORT_FILENAME_TIMESTAMP_FORMAT = "%Y%m%d"
 
@@ -351,11 +370,12 @@ LIST_MODEL_APP_LABEL = env.str("EDC_LIST_MODEL_APP_LABEL")
 SUBJECT_APP_LABEL = env.str("EDC_SUBJECT_APP_LABEL")
 SUBJECT_SCREENING_MODEL = env.str("EDC_SUBJECT_SCREENING_MODEL")
 SUBJECT_CONSENT_MODEL = env.str("EDC_SUBJECT_CONSENT_MODEL")
+SUBJECT_LOCATOR_MODEL = "intecomm_prn.subjectlocator"
+SUBJECT_REFUSAL_MODEL = env.str("EDC_REFUSAL_SUBJECT_REFUSAL_MODEL")
 SUBJECT_REQUISITION_MODEL = env.str("EDC_SUBJECT_REQUISITION_MODEL")
 SUBJECT_VISIT_MODEL = env.str("EDC_SUBJECT_VISIT_MODEL")
 SUBJECT_VISIT_MISSED_MODEL = env.str("EDC_SUBJECT_VISIT_MISSED_MODEL")
 SUBJECT_VISIT_MISSED_REASONS_MODEL = env.str("EDC_SUBJECT_VISIT_MISSED_REASONS_MODEL")
-
 EDC_BLOOD_RESULTS_MODEL_APP_LABEL = "intecomm_subject"
 
 EDC_NAVBAR_DEFAULT = env("EDC_NAVBAR_DEFAULT")
@@ -367,11 +387,17 @@ DASHBOARD_BASE_TEMPLATES = env.dict("DJANGO_DASHBOARD_BASE_TEMPLATES")
 LAB_DASHBOARD_BASE_TEMPLATES = env.dict("DJANGO_LAB_DASHBOARD_BASE_TEMPLATES")
 LAB_DASHBOARD_URL_NAMES = env.dict("DJANGO_LAB_DASHBOARD_URL_NAMES")
 
+# edc-consent
+EDC_CONSENT_REMOVE_PATIENT_NAMES_FROM_COUNTRIES = env.list(
+    "EDC_CONSENT_REMOVE_PATIENT_NAMES_FROM_COUNTRIES", default=[]
+)
+
 # edc-diagnosis
 EDC_DX_LABELS = dict(hiv="HIV", dm="Diabetes", htn="Hypertension")
 
 # edc-dx-review
 EDC_DX_REVIEW_APP_LABEL = "intecomm_subject"
+EDC_DX_REVIEW_LIST_MODEL_APP_LABEL = "edc_dx_review"
 # edc_facility
 HOLIDAY_FILE = env.str("DJANGO_HOLIDAY_FILE")
 
@@ -487,8 +513,10 @@ if env("AWS_ENABLED"):
     STATIC_URL = f"{os.path.join(AWS_S3_CUSTOM_DOMAIN, AWS_LOCATION)}/"
     STATIC_ROOT = ""
 elif DEBUG:
-    STATIC_URL = env.str("DJANGO_STATIC_URL")
-    STATIC_ROOT = os.path.expanduser("~/source/edc_source/intecomm-edc/static/")
+    STATIC_URL = "static/"  # env.str("DJANGO_STATIC_URL")
+    STATIC_ROOT = env.str("DJANGO_STATIC_ROOT") or os.path.expanduser(
+        "~/source/edc_source/intecomm-edc/static/"
+    )
 else:
     # run collectstatic, check nginx LOCATION
     STATIC_URL = env.str("DJANGO_STATIC_URL")
@@ -512,3 +540,4 @@ if "test" in sys.argv:
 
 INTECOMM_MIN_GROUP_SIZE = 14
 INTECOMM_MIN_GROUP_SIZE_FOR_RATIO = 9
+INTECOMM_MAX_MONTHS_TO_NEXT_APPT = 7
