@@ -3,11 +3,9 @@ from .patient_followup_call import PatientFollowupCall
 from .patient_group import PatientGroup
 from .patient_group_appointment import PatientGroupAppointment
 from .patient_group_meeting import PatientGroupMeeting
-
-# from .proxy_models import PatientLog
 from .signals import (
-    create_or_update_patient_group_meeting_on_post_save,
-    update_patient_group_ratio_on_post_save,
-    update_patients_from_m2ms_on_m2m_changed,
+    create_or_update_patientgroup_meeting_on_post_save,
+    update_patientgroup_on_post_save,
+    update_patientgroup_patients_from_patientlog_m2ms_on_m2m_changed,
 )
 from .utils import add_to_group, remove_from_group
