@@ -1,5 +1,6 @@
 from django.db import models
 from edc_model.models import BaseUuidModel
+from edc_sites.model_mixins import SiteModelMixin
 from edc_utils import get_utcnow
 from edc_visit_tracking.constants import SCHEDULED
 
@@ -7,11 +8,8 @@ from ..choices import MEETING_STATUS
 from ..constants import ATTENDED
 from .patient_group_appointment import PatientGroupAppointment
 
-# from intecomm_screening.models import PatientLog
-
-
-class PatientGroupMeeting(BaseUuidModel):
 
+class PatientGroupMeeting(SiteModelMixin, BaseUuidModel):
     patient_group_appointment = models.OneToOneField(
         PatientGroupAppointment,
         on_delete=models.PROTECT,
@@ -28,6 +26,8 @@ class PatientGroupMeeting(BaseUuidModel):
 
     notes = models.TextField(null=True, blank=True)
 
+    # duration,
+
     def __str__(self):
         return self.patient_group_appointment.patient_group.name
 
@@ -36,4 +36,5 @@ class PatientGroupMeeting(BaseUuidModel):
         super().save(*args, **kwargs)
 
     class Meta(BaseUuidModel.Meta):
-        pass
+        verbose_name = "Patient Group Meeting"
+        verbose_name_plural = "Patient Groups Meeting"
