@@ -3,10 +3,9 @@ from django.contrib import admin
 from ..admin_site import intecomm_prn_admin
 from ..forms import OffScheduleCommForm
 from ..models import OffScheduleComm
-from .offschedule_inte_admin import OffScheduleInteAdmin
+from .modeladmin_mixins import OffScheduleAdmin
 
 
 @admin.register(OffScheduleComm, site=intecomm_prn_admin)
-class OffScheduleCommAdmin(OffScheduleInteAdmin):
-
+class OffScheduleCommAdmin(OffScheduleAdmin):
     form = OffScheduleCommForm
