@@ -2,10 +2,9 @@ from django.contrib import admin
 
 from ..admin_site import intecomm_prn_admin
 from ..models import OnScheduleComm
-from .onschedule_inte_admin import OnScheduleInteAdmin
+from .modeladmin_mixins import OnScheduleModelAdmin
 
 
 @admin.register(OnScheduleComm, site=intecomm_prn_admin)
-class OnScheduleCommAdmin(OnScheduleInteAdmin):
-
+class OnScheduleCommAdmin(OnScheduleModelAdmin):
     pass
