@@ -7,10 +7,9 @@ from ..constants import OFFSCHEDULE_COMM_ACTION
 
 
 class OffScheduleComm(SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
-
     action_name = OFFSCHEDULE_COMM_ACTION
     offschedule_compare_dates_as_datetimes = False
 
     class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
-        verbose_name = "Off-schedule Community Integrated Care"
-        verbose_name_plural = "Off-schedule Community Integrated Care"
+        verbose_name = "Off-schedule community-based integrated care"
+        verbose_name_plural = "Off-schedule community-based integrated care"
