@@ -7,10 +7,9 @@ from ..constants import OFFSCHEDULE_INTE_ACTION
 
 
 class OffScheduleInte(SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
-
     action_name = OFFSCHEDULE_INTE_ACTION
     offschedule_compare_dates_as_datetimes = False
 
     class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
-        verbose_name = "Off-schedule Facility Integrated Care"
-        verbose_name_plural = "Off-schedule Facility Integrated Care"
+        verbose_name = "Off-schedule facility-based integrated care"
+        verbose_name_plural = "Off-schedule facility-based integrated care"
