@@ -8,5 +8,5 @@ class OnScheduleInte(SiteModelMixin, OnScheduleModelMixin, BaseUuidModel):
     """A model used by the system. Auto-completed by subject_consent."""
 
     class Meta(OnScheduleModelMixin.Meta, BaseUuidModel.Meta):
-        verbose_name = "On-schedule Facility Integrated Care"
-        verbose_name_plural = "On-schedule Facility Integrated Care"
+        verbose_name = "On-schedule facility-based integrated care"
+        verbose_name_plural = "On-schedule facility-based integrated care"
