@@ -1,15 +1,27 @@
+from __future__ import annotations
+
+import re
+import urllib.parse
+
 from django.contrib import admin
 from django.core.exceptions import ObjectDoesNotExist
 from django.template.loader import render_to_string
 from django.urls import reverse
 from django.utils.html import format_html
 from django_audit_fields import audit_fieldset_tuple
+from edc_consent.modeladmin_mixins import PiiNamesModelAdminMixin
+from edc_consent.utils import get_remove_patient_names_from_countries
 from edc_constants.choices import GENDER
+from edc_constants.constants import UUID_PATTERN
+from edc_model_admin.mixins import ModelAdminProtectPiiMixin
+from edc_sites.admin import SiteModelAdminMixin
+
+from intecomm_sites.sites import all_sites
 
 from ..admin_site import intecomm_screening_admin
 from ..forms import PatientLogForm
-from ..models import PatientGroup, PatientLog, SubjectScreening
-from ..utils import get_add_or_change_consent_url
+from ..models import PatientGroup, PatientLog
+from .actions import render_pdf_action
 from .list_filters import (
     AttendDateListFilter,
     ConsentedListFilter,
@@ -20,18 +32,46 @@ from .list_filters import (
     ScreenedListFilter,
     StableListFilter,
 )
-from .modeladmin_mixins import BaseModelAdminMixin
+from .modeladmin_mixins import (
+    BaseModelAdminMixin,
+    ChangeListTopBarModelAdminMixin,
+    RedirectAllToPatientLogModelAdminMixin,
+)
 from .patient_call_inlines import AddPatientCallInline, ViewPatientCallInline
+from .utils import ChangeListTemplateContext
 
 
 @admin.register(PatientLog, site=intecomm_screening_admin)
-class PatientLogAdmin(BaseModelAdminMixin):
-
+class PatientLogAdmin(
+    ModelAdminProtectPiiMixin,
+    SiteModelAdminMixin,
+    ChangeListTopBarModelAdminMixin,
+    RedirectAllToPatientLogModelAdminMixin,
+    PiiNamesModelAdminMixin,
+    BaseModelAdminMixin,
+):
     form = PatientLogForm
-    custom_form_codename = "edc_data_manager.special_bypassmodelform"
-    list_per_page = 20
+
+    autocomplete_fields = ["site"]
+    inlines = [AddPatientCallInline, ViewPatientCallInline]
+    actions = [render_pdf_action]
+    list_per_page = 5
     show_object_tools = True
     show_cancel = True
+
+    extra_pii_attrs = ["first_column"]
+    # extra_pii_attrs = [("first_column", "__str__"), ("screened", "screened_no_links")]
+
+    # PiiNamesModelAdminMixin attrs
+    name_fields: list[str] = ["legal_name", "familiar_name"]
+    name_display_field: str = "familiar_name"
+    all_sites = all_sites
+
+    # ChangeListTopBarModelAdminMixin attrs
+    changelist_top_bar_selected = "patientlog"
+    changelist_top_bar_add_url = "intecomm_screening_admin:intecomm_screening_patientlog_add"
+
+    custom_form_codename = "edc_data_manager.special_bypassmodelform"
     change_list_template: str = "intecomm_screening/admin/patientlog_change_list.html"
     change_list_title = PatientLog._meta.verbose_name
     change_list_note = format_html(
@@ -43,10 +83,6 @@ class PatientLogAdmin(BaseModelAdminMixin):
         'searching on a full name, put the full name in quotations, for example, "JOHN SMITH".'
     )
 
-    autocomplete_fields = ["site"]
-
-    inlines = [AddPatientCallInline, ViewPatientCallInline]
-
     additional_instructions = format_html(
         "Only include patients that are known to have a qualifying "
         "condition and are stable in-care.<BR>"
@@ -59,6 +95,8 @@ class PatientLogAdmin(BaseModelAdminMixin):
             None,
             {
                 "fields": (
+                    "patient_log_identifier",
+                    "filing_identifier",
                     "report_datetime",
                     "site",
                 )
@@ -121,6 +159,21 @@ class PatientLogAdmin(BaseModelAdminMixin):
                 )
             },
         ),
+        (
+            "Willingness to screen",
+            {
+                "description": (
+                    "This section may be left blank until a decision is made. If and when the "
+                    "screening form is submitted, the response here will be "
+                    "automatically updated by the EDC"
+                ),
+                "fields": (
+                    "willing_to_screen",
+                    "screening_refusal_reason",
+                    "screening_refusal_reason_other",
+                ),
+            },
+        ),
         (
             "Screening and Consent",
             {
@@ -133,12 +186,15 @@ class PatientLogAdmin(BaseModelAdminMixin):
                 ),
             },
         ),
+        (
+            "Group",
+            {"classes": ("collapse",), "fields": ("group_identifier",)},
+        ),
         audit_fieldset_tuple,
     )
 
     list_display = (
-        "__str__",
-        "hf_id",
+        "first_column",
         "dx",
         "group_name",
         "screened",
@@ -149,12 +205,14 @@ class PatientLogAdmin(BaseModelAdminMixin):
         "user_created",
         "created",
         "modified",
-        "screening_identifier",
-        "subject_identifier",
+        "screening_id",
+        "subject_id",
+        "site",
     )
 
     list_filter = (
         "report_datetime",
+        "willing_to_screen",
         "call_attempts",
         InPatientGroup,
         DxListFilter,
@@ -167,6 +225,7 @@ class PatientLogAdmin(BaseModelAdminMixin):
         "first_health_talk",
         "second_health_talk",
         "gender",
+        "printed",
     )
 
     filter_horizontal = ("conditions",)
@@ -175,14 +234,17 @@ class PatientLogAdmin(BaseModelAdminMixin):
         "id",
         "screening_identifier",
         "subject_identifier",
-        "last_4_hospital_identifier__exact",
-        "last_4_contact_number__exact",
         "hospital_identifier__exact",
         "initials__exact",
-        "legal_name__exact",
-        "familiar_name__exact",
+        "filing_identifier",
+        "patient_log_identifier",
+        "group_identifier",
         "contact_number__exact",
         "alt_contact_number__exact",
+        "last_4_hospital_identifier__exact",
+        "last_4_contact_number__exact",
+        "legal_name__exact",
+        "familiar_name__exact",
     )
 
     radio_fields = {
@@ -190,7 +252,10 @@ class PatientLogAdmin(BaseModelAdminMixin):
         "gender": admin.VERTICAL,
         "may_contact": admin.VERTICAL,
         "second_health_talk": admin.VERTICAL,
+        "site": admin.VERTICAL,
         "stable": admin.VERTICAL,
+        "screening_refusal_reason": admin.VERTICAL,
+        "willing_to_screen": admin.VERTICAL,
     }
 
     readonly_fields = (
@@ -198,11 +263,36 @@ class PatientLogAdmin(BaseModelAdminMixin):
         "screening_datetime",
         "subject_identifier",
         "consent_datetime",
+        "group_identifier",
+        "filing_identifier",
+        "patient_log_identifier",
     )
 
     def post_url_on_delete_kwargs(self, request, obj):
         return {}
 
+    @admin.display(description="Patient log", ordering="-modified")
+    def first_column(self, obj=None):
+        context = dict(
+            legal_name=obj.legal_name,
+            filing_identifier=obj.filing_identifier,
+            last_4_hospital_identifier=obj.last_4_hospital_identifier,
+            last_4_contact_number=obj.last_4_contact_number,
+            initials=obj.initials,
+            gender=obj.gender.upper(),
+            age_in_years=obj.age_in_years,
+        )
+        for country in get_remove_patient_names_from_countries():
+            if obj and obj.site.id in [s.site_id for s in self.all_sites.get(country)]:
+                context.pop("legal_name")
+                break
+        return format_html(
+            render_to_string(
+                "intecomm_screening/change_list_patient_log_first_column.html",
+                context=context,
+            )
+        )
+
     @admin.display(description="Date logged", ordering="report_datetime")
     def date_logged(self, obj=None):
         return obj.report_datetime.date()
@@ -215,15 +305,38 @@ class PatientLogAdmin(BaseModelAdminMixin):
     def last_appt(self, obj=None):
         return obj.last_appt_date
 
-    @admin.display(description="HF ID", ordering="hospital_identifier")
-    def hf_id(self, obj=None):
-        context = dict(hospital_identifier=obj.hospital_identifier)
+    # @admin.display(description="HF ID", ordering="hospital_identifier")
+    # def hf_id(self, obj=None):
+    #     context = dict(hospital_identifier=obj.hospital_identifier)
+    #     return format_html(
+    #         render_to_string(
+    #             "intecomm_screening/change_list_hospital_identifier.html", context=context
+    #         )
+    #     )
+
+    @admin.display(description="FILE", ordering="filing_identifier")
+    def filing_id(self, obj=None):
+        context = dict(filing_identifier=obj.filing_identifier)
         return format_html(
             render_to_string(
-                "intecomm_screening/change_list_hospital_identifier.html", context=context
+                "intecomm_screening/change_list_filing_identifier.html", context=context
             )
         )
 
+    @admin.display(description="Screening ID", ordering="screening_identifier")
+    def screening_id(self, obj=None):
+        return (
+            None
+            if re.match(UUID_PATTERN, obj.screening_identifier)
+            else obj.screening_identifier
+        )
+
+    @admin.display(description="Subject ID", ordering="subject_identifier")
+    def subject_id(self, obj=None):
+        return (
+            None if re.match(UUID_PATTERN, obj.subject_identifier) else obj.subject_identifier
+        )
+
     @admin.display(description="DX")
     def dx(self, obj=None):
         context = dict(
@@ -282,12 +395,21 @@ class PatientLogAdmin(BaseModelAdminMixin):
     def patient(self, obj=None):
         return f"{obj.familiar_name} ({obj.initials})"
 
-    @admin.display(description="Screen/Consent", ordering="screening_datetime")
+    @admin.display(description="Log/Scr/Consent", ordering="screening_datetime")
     def screened(self, obj=None):
         return format_html(
             render_to_string(
                 "intecomm_screening/change_list_screen_and_consent.html",
-                context=self.get_screening_context(obj),
+                context=self.get_screen_and_consent_template_context(obj),
+            )
+        )
+
+    @admin.display(description="Log/Scr/Consent", ordering="screening_datetime")
+    def screened_no_links(self, obj=None):
+        return format_html(
+            render_to_string(
+                "intecomm_screening/change_list_screen_and_consent.html",
+                context=self.get_screen_and_consent_template_context(obj),
             )
         )
 
@@ -302,11 +424,18 @@ class PatientLogAdmin(BaseModelAdminMixin):
         context = dict()
         if obj.patientgroup_set.all().count() > 0:
             patient_group = obj.patientgroup_set.all().first()
-            url = reverse(
+            patient_group_url = reverse(
                 "intecomm_screening_admin:intecomm_screening_patientgroup_changelist"
             )
-            url = f"{url}?q={patient_group.name}"
-            context.update(url=url, patient_group=patient_group)
+            patient_group_url = (
+                f"{patient_group_url}?q={urllib.parse.quote(patient_group.name)}"
+            )
+            context.update(
+                patient_group_url=patient_group_url,
+                patient_group_name=patient_group.name.replace(" ", "\n"),
+                subject_identifier=obj.subject_identifier,
+                subject_dashboard_url=self.get_subject_dashboard_url(obj),
+            )
         return format_html(
             render_to_string("intecomm_screening/change_list_group.html", context=context)
         )
@@ -329,75 +458,47 @@ class PatientLogAdmin(BaseModelAdminMixin):
             queryset,
             search_term,
         )
-        queryset_pks = [obj.pk for obj in queryset.all()]
         try:
-            patient_group = PatientGroup.objects.get(name__iexact=search_term)
+            patient_group = PatientGroup.on_site.prefetch_related("patients").get(
+                name__iexact=search_term
+            )
         except ObjectDoesNotExist:
             qs = qs1
         else:
-            pks = [obj.pk for obj in patient_group.patients.filter(pk__in=queryset_pks)]
-            qs = qs1 | self.model.objects.filter(id__in=pks)
+            pks = [v[0] for v in queryset.values_list("id")]
+            pks = [v[0] for v in patient_group.patients.filter(pk__in=pks).values_list("id")]
+            qs = qs1 | self.model.on_site.filter(id__in=pks)
         return qs, True
 
     @staticmethod
-    def get_screening_context(obj) -> dict:
-        add_screening_url = None
-        change_screening_url = None
-        add_consent_url = None
-        change_consent_url = None
-        subject_identifier = None
-        subject_screening = None
-        eligible = None
-        if obj.screening_identifier:
-            subject_screening = SubjectScreening.objects.get(
-                screening_identifier=obj.screening_identifier
+    def get_screen_and_consent_template_context(obj) -> dict:
+        """Context for change_list_screen_and_consent.html"""
+        return ChangeListTemplateContext(obj).context
+
+    @staticmethod
+    def get_subject_dashboard_url(obj):
+        subject_dashboard_url = None
+        if obj.subject_identifier and obj.group_identifier:
+            subject_dashboard_url = reverse(
+                "intecomm_dashboard:subject_dashboard_url",
+                args=(obj.subject_identifier,),
             )
-            eligible = subject_screening.eligible
-            url = reverse(
-                "intecomm_screening_admin:intecomm_screening_subjectscreening_change",
-                args=(subject_screening.id,),
+        return subject_dashboard_url
+
+    def report(self, obj=None):
+        return format_html(
+            render_to_string(
+                "intecomm_screening/change_list_screen_and_consent.html",
+                context=self.get_screen_and_consent_template_context(obj),
             )
-            change_screening_url = (
-                f"{url}?next=intecomm_screening_admin:intecomm_screening_patientlog_changelist"
-                f"&q={obj.screening_identifier}"
-            )
-        else:
-            url = reverse("intecomm_screening_admin:intecomm_screening_subjectscreening_add")
-            add_screening_url = (
-                f"{url}?next=intecomm_screening_admin:intecomm_screening_patientlog_changelist"
-                f"&hospital_identifier={obj.hospital_identifier}"
-                f"&initials={obj.initials}"
-                f"&site={obj.site.id}"
-                f"&gender={obj.gender}"
-                f"&age_in_years={obj.age_in_years}"
-                f"&legal_name={obj.legal_name}"
-                f"&familiar_name={obj.familiar_name}"
-                f"&patient_log={obj.id}"
-                f"&q={obj.screening_identifier}"
-            )
-        if subject_screening and subject_screening.eligible:
-            (
-                add_consent_url,
-                change_consent_url,
-                subject_identifier,
-            ) = get_add_or_change_consent_url(subject_screening)
-        stable_display = (
-            obj.get_stable_display()
-            if obj.get_stable_display() != "To be determined"
-            else "TBD"
-        )
-        return dict(
-            stable=stable_display,
-            add_screening_url=add_screening_url,
-            change_screening_url=change_screening_url,
-            add_consent_url=add_consent_url,
-            change_consent_url=change_consent_url,
-            screening_identifier=obj.screening_identifier,
-            subject_identifier=subject_identifier,
-            eligible=eligible,
         )
 
     def formfield_for_choice_field(self, db_field, request, **kwargs):
         if db_field.name == "gender":
             kwargs["choices"] = GENDER
         return super().formfield_for_choice_field(db_field, request, **kwargs)
+
+    def get_changeform_initial_data(self, request) -> dict:
+        dct = super().get_changeform_initial_data(request)
+        dct.update({"patient_log_identifier": "custom_initial_value"})
+        return dct
