@@ -1,13 +1,13 @@
 screening_codenames = [
-    "intecomm_screening.add_subjectrefusal",
-    "intecomm_screening.change_subjectrefusal",
-    "intecomm_screening.delete_subjectrefusal",
+    "intecomm_screening.add_consentrefusal",
+    "intecomm_screening.change_consentrefusal",
+    "intecomm_screening.delete_consentrefusal",
     "intecomm_screening.add_subjectscreening",
     "intecomm_screening.change_subjectscreening",
     "intecomm_screening.delete_subjectscreening",
     "intecomm_screening.view_historicalsubjectscreening",
-    "intecomm_screening.view_historicalsubjectrefusal",
+    "intecomm_screening.view_historicalconsentrefusal",
     "intecomm_screening.view_subjectscreening",
-    "intecomm_screening.view_subjectrefusal",
+    "intecomm_screening.view_consentrefusal",
 ]
 screening_codenames.sort()
