@@ -5,7 +5,9 @@ from faker import Faker
 from intecomm_form_validators import RECRUITING
 from model_bakery.recipe import Recipe
 
-from .models import PatientGroup, PatientLog
+from intecomm_lists.models import ConsentRefusalReasons
+
+from .models import ConsentRefusal, PatientGroup, PatientLog
 
 fake = Faker()
 
@@ -15,11 +17,18 @@ names = legal_name.split(" ")
 initials = f"{names[0][0]}{names[-1][0]}"
 
 
+consentrefusal = Recipe(
+    ConsentRefusal,
+    report_datetime=get_utcnow(),
+    reason=ConsentRefusalReasons.objects.get(name="dont_have_time"),
+)
+
 patientgroup = Recipe(
     PatientGroup,
     report_datetime=get_utcnow(),
     status=RECRUITING,
     randomize_now=NO,
+    group_identifier=None,
 )
 
 patientlog = Recipe(
@@ -28,8 +37,8 @@ patientlog = Recipe(
     familiar_name=familiar_name,
     initials=initials,
     report_datetime=get_utcnow(),
-    screening_identifier=None,
-    subject_identifier=None,
+    # screening_identifier=None,
+    # subject_identifier=None,
     consent_datetime=None,
     gender=MALE,
     may_contact=YES,
@@ -39,4 +48,6 @@ patientlog = Recipe(
     first_health_talk=YES,
     second_health_talk=YES,
     call_attempts=1,
+    willing_to_screen=YES,
+    screening_refusal_reason=None,
 )
