@@ -4,11 +4,10 @@ from edc_sites.models import CurrentSiteManager, SiteModelMixin
 
 
 class Location(SiteModelMixin, ListModelMixin):
-
     on_site = CurrentSiteManager()
     history = HistoricalRecords()
     objects = ListModelManager()
 
-    class Meta:
+    class Meta(ListModelMixin.Meta):
         verbose_name = "Location"
         verbose_name_plural = "Locations"
