@@ -1,5 +1,5 @@
 from django.contrib import admin
-from edc_model_admin.mixins import TabularInlineMixin
+from edc_model_admin.mixins import InlineHideOriginalObjectNameMixin, TabularInlineMixin
 from edc_rx.modeladmin_mixins import DrugRefillAdminMixin, DrugSupplyInlineMixin
 
 from ..admin_site import intecomm_subject_admin
@@ -8,12 +8,20 @@ from ..models import DrugRefillDm, DrugSupplyDm
 from .modeladmin_mixins import CrfModelAdmin
 
 
-class DrugSupplyDmInline(DrugSupplyInlineMixin, TabularInlineMixin, admin.TabularInline):
+class DrugSupplyDmInline(
+    DrugSupplyInlineMixin,
+    TabularInlineMixin,
+    admin.TabularInline,
+):
     model = DrugSupplyDm
     form = DrugSupplyDmForm
 
 
 @admin.register(DrugRefillDm, site=intecomm_subject_admin)
-class DrugRefillDmAdmin(DrugRefillAdminMixin, CrfModelAdmin):
+class DrugRefillDmAdmin(
+    DrugRefillAdminMixin,
+    InlineHideOriginalObjectNameMixin,
+    CrfModelAdmin,
+):
     form = DrugRefillDmForm
     inlines = [DrugSupplyDmInline]
