@@ -1,5 +1,5 @@
 from django.contrib import admin
-from edc_model_admin.mixins import TabularInlineMixin
+from edc_model_admin.mixins import InlineHideOriginalObjectNameMixin, TabularInlineMixin
 from edc_rx.modeladmin_mixins import DrugRefillAdminMixin, DrugSupplyInlineMixin
 
 from ..admin_site import intecomm_subject_admin
@@ -14,6 +14,15 @@ class DrugSupplyHtnInline(DrugSupplyInlineMixin, TabularInlineMixin, admin.Tabul
 
 
 @admin.register(DrugRefillHtn, site=intecomm_subject_admin)
-class DrugRefillHtnAdmin(DrugRefillAdminMixin, CrfModelAdmin):
+class DrugRefillHtnAdmin(
+    DrugRefillAdminMixin,
+    InlineHideOriginalObjectNameMixin,
+    CrfModelAdmin,
+):
     form = DrugRefillHtnForm
     inlines = [DrugSupplyHtnInline]
+
+    def get_formset(self, request, obj=None, **kwargs):
+        formset = super().get_formset(request, obj=None, **kwargs)
+        formset.insert_before_fieldset = self.insert_before_fieldset
+        return formset
