@@ -3,25 +3,34 @@ from django_audit_fields.admin import audit_fieldset_tuple
 from edc_crf.admin import crf_status_fieldset_tuple
 
 from ..admin_site import intecomm_subject_admin
+from ..forms import HtnInitialReviewForm
 from ..models import HtnInitialReview
 from .modeladmin_mixins import CrfModelAdmin
 
 
 @admin.register(HtnInitialReview, site=intecomm_subject_admin)
 class HtnInitialReviewAdmin(CrfModelAdmin):
-
-    # form = HtnInitialReviewForm
+    form = HtnInitialReviewForm
 
     fieldsets = (
         (None, {"fields": ("subject_visit", "report_datetime")}),
         (
-            "Diagnosis and Treatment",
+            "Hypertension diagnosis",
             {
                 "fields": (
-                    "dx_ago",
                     "dx_date",
+                    "dx_ago",
+                )
+            },
+        ),
+        (
+            "Hypertension treatment",
+            {
+                "fields": (
                     "managed_by",
-                    "med_start_ago",
+                    "managed_by_other",
+                    "rx_init_date",
+                    "rx_init_ago",
                 )
             },
         ),
@@ -31,5 +40,12 @@ class HtnInitialReviewAdmin(CrfModelAdmin):
 
     radio_fields = {
         "crf_status": admin.VERTICAL,
-        "managed_by": admin.VERTICAL,
+        # "managed_by": admin.VERTICAL,
     }
+
+    filter_horizontal = ["managed_by"]
+
+    def get_form(self, request, obj=None, **kwargs):
+        form = super().get_form(request, obj=obj, **kwargs)
+        form = self.replace_label_text(form, "diagnosis_label", self.model.diagnosis_label)
+        return form
