@@ -1,17 +1,10 @@
 APPT = "appt"
 APPT_OTHER = "other_routine_appt"
 COMMUNITY_CLINIC = "community_clinic"
-DIET_LIFESTYLE = "diet_lifestyle"
-DRUGS = "drugs"
 GTE_3HRS = "gte_3hr"
-HEALTH_FACILITY = "health_facility"
-HIV = "hiv"
-INSULIN = "insulin"
-INTEGRATED = "integrated"
 MISSED_VISIT_ACTION = "missed_visit_action"
-NCD = "ncd"
+NOT_SCHEDULED_FOR_FACILITY = "NOT_SCHEDULED_FOR_FACILITY"
 NURSE = "nurse"
 SITTING = "sitting"
-THIS_CLINIC = "this_clinic"
 VERTICAL = "vertical"
 VIT_B_FOLIC_ACID = "vitamin_b_folic_acid"
