@@ -1,15 +1,13 @@
 from edc_constants.constants import NO, NOT_APPLICABLE, YES
+from edc_he.rule_groups import HealthEconomicsRuleGroup as BaseHealthEconomicsRuleGroup
 from edc_metadata import NOT_REQUIRED, REQUIRED
 from edc_metadata.metadata_rules import CrfRule, CrfRuleGroup, P, register
 
-from .predicates import Predicates
-
-pc = Predicates()
+from .predicates import HealthEconomicsPredicates
 
 
 @register()
 class ClinicalReviewBaselineRuleGroup(CrfRuleGroup):
-
     hiv = CrfRule(
         predicate=P("hiv_dx", "eq", YES),
         consequence=REQUIRED,
@@ -38,43 +36,42 @@ class ClinicalReviewBaselineRuleGroup(CrfRuleGroup):
 
 @register()
 class ClinicalReviewRuleGroup(CrfRuleGroup):
-
-    hiv_dx = CrfRule(
+    hiv_initial = CrfRule(
         predicate=P("hiv_dx", "eq", YES),
         consequence=REQUIRED,
         alternative=NOT_REQUIRED,
         target_models=["hivinitialreview"],
     )
 
-    dm_dx = CrfRule(
+    dm_initial = CrfRule(
         predicate=P("dm_dx", "eq", YES),
         consequence=REQUIRED,
         alternative=NOT_REQUIRED,
         target_models=["dminitialreview"],
     )
 
-    htn_dx = CrfRule(
+    htn_initial = CrfRule(
         predicate=P("htn_dx", "eq", YES),
         consequence=REQUIRED,
         alternative=NOT_REQUIRED,
         target_models=["htninitialreview"],
     )
 
-    hiv_test = CrfRule(
+    hiv_review = CrfRule(
         predicate=P("hiv_test", "eq", NOT_APPLICABLE),
         consequence=REQUIRED,
         alternative=NOT_REQUIRED,
         target_models=["hivreview"],
     )
 
-    dm_test = CrfRule(
+    dm_review = CrfRule(
         predicate=P("dm_test", "eq", NOT_APPLICABLE),
         consequence=REQUIRED,
         alternative=NOT_REQUIRED,
         target_models=["dmreview"],
     )
 
-    htn_test = CrfRule(
+    htn_review = CrfRule(
         predicate=P("htn_test", "eq", NOT_APPLICABLE),
         consequence=REQUIRED,
         alternative=NOT_REQUIRED,
@@ -95,7 +92,6 @@ class ClinicalReviewRuleGroup(CrfRuleGroup):
 
 @register()
 class MedicationsRuleGroup(CrfRuleGroup):
-
     refill_hiv = CrfRule(
         predicate=P("refill_hiv", "eq", YES),
         consequence=REQUIRED,
@@ -141,3 +137,11 @@ class MedicationsRuleGroup(CrfRuleGroup):
     class Meta:
         app_label = "intecomm_subject"
         source_model = "intecomm_subject.medications"
+
+
+@register()
+class HealthEconomicsRuleGroup(BaseHealthEconomicsRuleGroup):
+    class Meta:
+        app_label = "intecomm_subject"
+        source_model = "intecomm_subject.subjectvisit"
+        predicates = HealthEconomicsPredicates()
