@@ -1,4 +1,5 @@
 from django.db import models
+from edc_crf.model_mixins import CrfStatusModelMixin
 from edc_lab.model_mixins import CrfWithRequisitionModelMixin, requisition_fk_options
 from edc_lab_panel.panels import blood_glucose_panel
 from edc_lab_results import BLOOD_RESULTS_GLU_ACTION
@@ -14,6 +15,7 @@ class BloodResultsGlu(
     GlucoseModelMixin,
     CrfWithRequisitionModelMixin,
     BloodResultsModelMixin,
+    CrfStatusModelMixin,
     BaseUuidModel,
 ):
     action_name = BLOOD_RESULTS_GLU_ACTION
