@@ -1,4 +1,5 @@
 from django.db import models
+from edc_crf.model_mixins import CrfStatusModelMixin
 from edc_lab.model_mixins import CrfWithRequisitionModelMixin, requisition_fk_options
 from edc_lab_panel.panels import hba1c_panel
 from edc_lab_results import BLOOD_RESULTS_HBA1C_ACTION
@@ -13,6 +14,7 @@ class BloodResultsHba1c(
     Hba1cModelMixin,
     CrfWithRequisitionModelMixin,
     BloodResultsModelMixin,
+    CrfStatusModelMixin,
     BaseUuidModel,
 ):
     action_name = BLOOD_RESULTS_HBA1C_ACTION
