@@ -1,4 +1,5 @@
 from django.db import models
+from edc_crf.model_mixins import CrfStatusModelMixin
 from edc_lab.model_mixins import CrfWithRequisitionModelMixin, requisition_fk_options
 from edc_lab_panel.panels import lipids_panel
 from edc_lab_results import BLOOD_RESULTS_LIPID_ACTION
@@ -22,6 +23,7 @@ class BloodResultsLipid(
     CholModelMixin,
     CrfWithRequisitionModelMixin,
     BloodResultsModelMixin,
+    CrfStatusModelMixin,
     BaseUuidModel,
 ):
     action_name = BLOOD_RESULTS_LIPID_ACTION
