@@ -6,7 +6,6 @@ from ..model_mixins import CrfModelMixin
 
 
 class UrinePregnancy(CrfModelMixin, edc_models.BaseUuidModel):
-
     performed = models.CharField(
         verbose_name="Was the urine pregnancy test performed?",
         max_length=15,
@@ -38,4 +37,5 @@ class UrinePregnancy(CrfModelMixin, edc_models.BaseUuidModel):
     )
 
     class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
-        verbose_name = "Urine Pregnancy"
+        verbose_name = "Urine pregnancy test"
+        verbose_name_plural = "Urine pregnancy tests"
