@@ -1,4 +1,6 @@
 COMM_SCHEDULE = "comm_schedule"
+COMMUNITY_SCHEDULE = "comm_schedule"
 INTE_SCHEDULE = "inte_schedule"
+FACILITY_SCHEDULE = "inte_schedule"
 SCHEDULE = "schedule"
 VISIT_SCHEDULE = "visit_schedule"
