@@ -30,39 +30,6 @@ requisitions_unscheduled = FormsCollection(
 requisitions_d1 = FormsCollection(
     name="requisitions_day1",
 )
-requisitions_1m = FormsCollection(
-    name="requisitions_1m",
-)
-requisitions_2m = FormsCollection(
-    name="requisitions_2m",
-)
-requisitions_3m = FormsCollection(
-    name="requisitions_3m",
-)
-requisitions_4m = FormsCollection(
-    name="requisitions_4m",
-)
-requisitions_5m = FormsCollection(
-    name="requisitions_5m",
-)
-requisitions_6m = FormsCollection(
-    name="requisitions_6m",
-)
-requisitions_7m = FormsCollection(
-    name="requisitions_7m",
-)
-requisitions_8m = FormsCollection(
-    name="requisitions_8m",
-)
-requisitions_9m = FormsCollection(
-    name="requisitions_9m",
-)
-requisitions_10m = FormsCollection(
-    name="requisitions_10m",
-)
-requisitions_11m = FormsCollection(
-    name="requisitions_11m",
-)
-requisitions_12m = FormsCollection(
-    name="requisitions_month12",
+requisitions_followup = FormsCollection(
+    name="requisitions_followup",
 )
