@@ -17,6 +17,7 @@ project_settings = DefaultTestSettings(
     ROOT_URLCONF="intecomm_edc.urls",
     EDC_AUTH_CODENAMES_WARN_ONLY=True,
     EDC_DX_REVIEW_LIST_MODEL_APP_LABEL="edc_dx_review",
+    EDC_DX_REVIEW_APP_LABEL="intecomm_subject",
     BASE_DIR=base_dir,
     APP_NAME=app_name,
     SITE_ID=SiteID(default=101),
@@ -36,11 +37,17 @@ project_settings = DefaultTestSettings(
     SUBJECT_VISIT_MISSED_MODEL="intecomm_subject.subjectvisitmissed",
     SUBJECT_CONSENT_MODEL="intecomm_consent.subjectconsent",
     SUBJECT_REQUISITION_MODEL="intecomm_subject.subjectrequisition",
+    SUBJECT_LOCATOR_MODEL="intecomm_prn.subjectlocator",
+    EDC_HE_ASSETS_MODEL="intecomm_subject.healtheconomicsassets",
+    EDC_HE_HOUSEHOLDHEAD_MODEL="intecomm_subject.healtheconomicshouseholdhead",
+    EDC_HE_INCOME_MODEL="intecomm_subject.healtheconomicsincome",
+    EDC_HE_PATIENT_MODEL="intecomm_subject.healtheconomicspatient",
+    EDC_HE_PROPERTY_MODEL="intecomm_subject.healtheconomicsproperty",
     EDC_BLOOD_RESULTS_MODEL_APP_LABEL="intecomm_subject",
     DEFENDER_ENABLED=False,
     DJANGO_LAB_DASHBOARD_REQUISITION_MODEL="intecomm_subject.subjectrequisition",
     ADVERSE_EVENT_ADMIN_SITE="intecomm_ae_admin",
-    EDC_DX_LABELS=dict(hiv="HIV", dm="Diabetes", htn="Hypertension", chol="High Cholesterol"),
+    EDC_DX_LABELS=dict(hiv="HIV", dm="Diabetes", htn="Hypertension"),
     ADVERSE_EVENT_APP_LABEL="intecomm_ae",
     EDC_NAVBAR_DEFAULT="intecomm_dashboard",
     EDC_PROTOCOL_STUDY_OPEN_DATETIME=datetime(2019, 4, 30, 0, 0, 0, tzinfo=ZoneInfo("UTC")),
@@ -59,7 +66,12 @@ project_settings = DefaultTestSettings(
         listboard_base_template="intecomm_edc/base.html",
         dashboard_base_template="intecomm_edc/base.html",
         screening_listboard_template="intecomm_dashboard/screening/listboard.html",
-        subject_listboard_template="intecomm_dashboard/subject/listboard.html",
+        comm_subject_listboard_template=(
+            "intecomm_dashboard/bootstrap3/subject/comm_listboard.html"
+        ),
+        inte_subject_listboard_template=(
+            "intecomm_dashboard/bootstrap3/subject/inte_listboard.html"
+        ),
         subject_dashboard_template="intecomm_dashboard/subject/dashboard.html",
         subject_review_listboard_template="edc_review_dashboard/subject_review_listboard.html",
     ),
@@ -94,67 +106,75 @@ project_settings = DefaultTestSettings(
         "simple_history",
         "storages",
         "edc_action_item.apps.AppConfig",
-        "edc_adverse_event.apps.AppConfig",
         "edc_appointment.apps.AppConfig",
         "edc_auth.apps.AppConfig",
-        "edc_model_wrapper.apps.AppConfig",
-        "edc_crf.apps.AppConfig",
-        "edc_data_manager.apps.AppConfig",
+        "edc_adverse_event.apps.AppConfig",
         "edc_consent.apps.AppConfig",
+        "edc_crf.apps.AppConfig",
+        "edc_reportable.apps.AppConfig",
+        "edc_lab.apps.AppConfig",
+        "edc_visit_schedule.apps.AppConfig",
+        "edc_visit_tracking.apps.AppConfig",
+        "edc_dx.apps.AppConfig",
+        "edc_dx_review.apps.AppConfig",
         "edc_device.apps.AppConfig",
         "edc_dashboard.apps.AppConfig",
-        "edc_egfr.apps.AppConfig",
+        "edc_data_manager.apps.AppConfig",
         "edc_export.apps.AppConfig",
         "edc_facility.apps.AppConfig",
         "edc_fieldsets.apps.AppConfig",
         "edc_form_validators.apps.AppConfig",
-        "edc_reportable.apps.AppConfig",
-        "edc_lab.apps.AppConfig",
+        "edc_he.apps.AppConfig",
         "edc_lab_dashboard.apps.AppConfig",
         "edc_label.apps.AppConfig",
+        "edc_list_data.apps.AppConfig",
         "edc_listboard.apps.AppConfig",
-        "edc_locator.apps.AppConfig",
-        "edc_reference.apps.AppConfig",
-        "edc_pdf_reports.apps.AppConfig",
         "edc_identifier.apps.AppConfig",
+        "edc_locator.apps.AppConfig",
         "edc_metadata.apps.AppConfig",
+        "edc_model.apps.AppConfig",
+        "edc_model_fields.apps.AppConfig",
         "edc_model_admin.apps.AppConfig",
         "edc_navbar.apps.AppConfig",
+        "edc_next_appointment.apps.AppConfig",
         "edc_notification.apps.AppConfig",
         "edc_offstudy.apps.AppConfig",
-        "edc_visit_tracking.apps.AppConfig",
-        "edc_visit_schedule.apps.AppConfig",
-        "edc_pdutils.apps.AppConfig",
         "edc_pharmacy.apps.AppConfig",
+        "edc_pdutils.apps.AppConfig",
         "edc_protocol.apps.AppConfig",
         "edc_protocol_incident.apps.AppConfig",
         "edc_prn.apps.AppConfig",
+        "edc_qol.apps.AppConfig",
         "edc_randomization.apps.AppConfig",
-        "edc_registration.apps.AppConfig",
-        "edc_subject_dashboard.apps.AppConfig",
-        "edc_screening.apps.AppConfig",
-        "edc_timepoint.apps.AppConfig",
-        "edc_list_data.apps.AppConfig",
-        "edc_review_dashboard.apps.AppConfig",
+        "edc_reference.apps.AppConfig",
         "edc_refusal.apps.AppConfig",
-        "edc_sites.apps.AppConfig",
-        "edc_dx.apps.AppConfig",
-        "edc_dx_review.apps.AppConfig",
+        "edc_registration.apps.AppConfig",
+        "edc_pdf_reports.apps.AppConfig",
+        "edc_review_dashboard.apps.AppConfig",
         "edc_rx.apps.AppConfig",
+        "edc_screening.apps.AppConfig",
+        "edc_sites.apps.AppConfig",
+        "edc_subject_dashboard.apps.AppConfig",
+        "edc_timepoint.apps.AppConfig",
+        "edc_unblinding.apps.AppConfig",
+        "edc_form_describer.apps.AppConfig",
+        "edc_adherence.apps.AppConfig",
         "canned_views.apps.AppConfig",
-        "intecomm_auth.apps.AppConfig",
+        "intecomm_rando.apps.AppConfig",
         "intecomm_consent.apps.AppConfig",
         "intecomm_lists.apps.AppConfig",
         "intecomm_dashboard.apps.AppConfig",
+        "intecomm_facility.apps.AppConfig",
         "intecomm_labs.apps.AppConfig",
         "intecomm_subject.apps.AppConfig",
         "intecomm_visit_schedule.apps.AppConfig",
         "intecomm_ae.apps.AppConfig",
+        "intecomm_auth.apps.AppConfig",
         "intecomm_prn.apps.AppConfig",
         "intecomm_export.apps.AppConfig",
-        "intecomm_rando.apps.AppConfig",
         "intecomm_group.apps.AppConfig",
         "intecomm_screening.apps.AppConfig",
+        "intecomm_sites.apps.AppConfig",
         "intecomm_edc.apps.AppConfig",
     ],
     add_dashboard_middleware=True,
@@ -165,6 +185,7 @@ project_settings = DefaultTestSettings(
 
 def main():
     tests = [
+        "intecomm_auth.tests",
         "intecomm_ae.tests",
         "intecomm_dashboard.tests",
         "intecomm_edc.tests",
@@ -172,10 +193,13 @@ def main():
         "intecomm_lists.tests",
         "intecomm_prn.tests",
         "intecomm_group.tests",
-        "intecomm_rando.tests",
         "intecomm_screening.tests",
         "intecomm_subject.tests",
+        "intecomm_consent.tests",
         "intecomm_visit_schedule.tests",
+        "intecomm_form_validators.tests",
+        "intecomm_rando.tests",
+        "intecomm_eligibility.tests",
     ]
 
     func_main(project_settings, *tests)
